CREATE GRAIN medstaff VERSION '1.07';

-- *** TABLES ***
create table student_cycle(
  person_id varchar(30) not null,
  cycle_id varchar(36) not null,
  course_id varchar(36) not null,  
  student_certificate VARCHAR(36) not null,
  cycle_open bit default 0,
  start_date DATETIME,
  end_date DATETIME,
  cycle_score INT,
  cycle_mark INT,
  cycle_order int,
  CONSTRAINT pk_student_cycle PRIMARY KEY (person_id,course_id,cycle_id,student_certificate)
);

create table student_program(
  person_id varchar(30) not null,
  course_id varchar(36) not null,
  student_certificate VARCHAR(36) not null,
  start_date DATETIME,
  end_date DATETIME,
  course_score INT,
  course_mark INT,
  course_open bit default 0,
  CONSTRAINT pk_student_program PRIMARY KEY (person_id,course_id, student_certificate)
);

CREATE TABLE student_certificate(
  uid VARCHAR(36) NOT NULL,
  /**ФЛ*/
  person_id VARCHAR(30) NOT NULL,
  course_id VARCHAR(36) NOT NULL,
  cycle_id VARCHAR(36),
  name text not null,
  patronymic text not null,
  surname text not null,
  organization_name text not null,
  organization_head text not null,
  snils text not null,
  certificate_number text,
  position text,
--  status varchar(30),
  status int,
  birth_date datetime,
  org_address text,
  issue_date datetime,
  CONSTRAINT pk_student_certificate PRIMARY KEY (uid)
);

CREATE TABLE certificate_address(
  certificate_id VARCHAR(36) NOT NULL,
  aoid VARCHAR(36),
  house_id VARCHAR(36),
  region_id VARCHAR(36),
  region_name VARCHAR(250),
  city_id VARCHAR(36),
  city_name VARCHAR(250),
  street_id VARCHAR(36),
  street_name VARCHAR(250),
  address VARCHAR(1000),
  address_additional VARCHAR(100),
  postcode VARCHAR(6),
  CONSTRAINT pk_cycle_address PRIMARY KEY (certificate_id)
);

--CREATE TABLE qti_variant_answer (
--  person_id VARCHAR(30) NOT NULL,  
--  student_certificate VARCHAR(36) not null,
--  cycle_id VARCHAR(36) NOT NULL,
--  package_id VARCHAR(36) NOT NULL,
--  package_name VARCHAR(50) NOT NULL,
--  variant_answer_id VARCHAR(36),
--  variant_id VARCHAR(36),
--  variant_name VARCHAR(255),
--  time_begin DATETIME,
--  time_end DATETIME,
--  score INT,
--  testing_mark INT,
--  time_finish DATETIME,
--  positive_count INT,
--  attempts_count INT default 0,
--  CONSTRAINT pk_qti_variant_answer PRIMARY KEY (person_id, student_certificate, cycle_id, package_id)
--) WITH NO VERSION CHECK;


/** Учебная программа пользователя */
CREATE TABLE student_eor_tasks (
  task_id INT IDENTITY NOT NULL PRIMARY KEY,
  student_certificate VARCHAR(36) not null,
  cycle_id VARCHAR(36) NOT NULL,
  package_id VARCHAR(36) NOT NULL,
  package_name VARCHAR(255) NOT NULL,
  eor_type int default 1,
  control_type int default 1,
  qti_order int default 1, 
  variant_id VARCHAR(36), 
  variant_name VARCHAR(255),
  attempts_count INT default 0,
  score INT,
  score_date DATETIME
);

/** Файлы пользователя */
CREATE TABLE practical_files (
  id INT IDENTITY NOT NULL PRIMARY KEY,	
  task_id int not null,
  file_name VARCHAR(255) not null,
  file_resource blob not null
) WITH NO VERSION CHECK;

create view vw_certificate as
select
	sc.uid as uid,
	sc.person_id as person_id,
	sc.course_id as course_id,
	course.name as course_name,
	sc.name as name,
	sc.patronymic as patronymic,
	sc.surname as surname,
	sc.snils as snils,
	sc.certificate_number as certificate_number,
	sc.position as position,
	sl.id as status_id,
	sl.name as status,
	sc.birth_date as birth_date,
	sc.issue_date as issue_date,
	stp.start_date as start_date,
	stp.end_date as end_date,
	sp.uid as spec_id,
	sp.name as spec_name,
	eo.shortname as edu_org_name,
	eo.uid as edu_org_id,
	p.email
from medstaff.student_certificate as sc
	left join medstaff.student_program as stp on stp.student_certificate = sc.uid
	inner join edu.course as course on course.uid  = sc.course_id
	inner join nci.edu_organization as eo on eo.uid = course.edu_organization_id
	inner join umk.speciality as sp on sp.uid = course.speciality_id
	inner join nci.status_list as sl on sc.status = sl.id
	inner join nci.person p on p.uid=sc.person_id;

create view vw_student_program as
select 
  sp.course_id as course_id,
  sp.person_id as person_id,
  sp.student_certificate as certificate,
  course.edu_organization_id AS edu_organization_id,
  course.name as name,
  course.speciality_id AS speciality_id,
  sp.start_date AS start_date,
  sp.end_date AS end_date, 
  course.hours AS hours,
  course.extramural_hours as extramural_hours,
  course.program_link as program_link,
  course.osk as osk,
  course.osk_hours as osk_hours, 
  course.internship as internship,
  course.internship_hours as internship_hours,
  course.edu_cost as price,
  course.str_unit as str_unit,
  course.dot_and_eo as dot_eo,
  spec.name as speciality_name,
  eo.name as edu_org_name,
  eo.shortname as edu_org_shortname,
  course.isCertification as is_certification,
  sl.id as status_id,
  sl.name as status,
  sp.course_open
from medstaff.student_program as sp
  inner join medstaff.student_certificate sf on sf.uid = sp.student_certificate
  inner join nci.status_list as sl on sf.status = sl.id
  inner join edu.course as course on course.uid = sp.course_id
  inner join umk.speciality as spec on spec.uid = course.speciality_id
  inner join nci.edu_organization as eo on eo.uid = course.edu_organization_id;

create view vw_student_cycle as
select
  sc.person_id as person_id,
  sc.cycle_id as cycle_id,
  sc.course_id as course_id,
  sc.student_certificate as certificate,
  cc.note as name,
  sc.cycle_open as cycle_open,
  sc.start_date as start_date,
  sc.end_date as end_date,
  sc.cycle_score as cycle_score,
  sc.cycle_mark as cycle_mark,
  cc.dot_and_eo as dot_and_eo,
  cc.outside as outside,
  sc.cycle_order as cycle_order
from medstaff.student_cycle as sc
inner join edu.course_cycle as cc on cc.uid=sc.cycle_id;